=========
Changelog
=========

Version 0.0.3
=============
- Fixing logo

Version 0.0.2
=============
- Working coverage reports
- Adding logo
- Project is ready for work

Version 0.0.1
=============

- Initial Setup
